@@ -84,18 +84,18 @@ def _check_error(r: requests.models.Response) -> Union[dict, list]:
     raise _create_exception(parsed_response, r.status_code, reason, r.url)
 
 
-def all_references(base_url: str, auth: Optional[AuthBase], ssl_verify: bool = True, fetch_additional_info: bool = False) -> dict:
+def all_references(base_url: str, auth: Optional[AuthBase], ssl_verify: bool = True, fetch_all: bool = False) -> dict:
     """Fetch all known references.
 
     :param base_url: base Nessie url
     :param auth: Authentication settings
     :param ssl_verify: ignore ssl errors if False
-    :param fetch_additional_info: indicates whether additional metadata should be fetched
+    :param fetch_all: indicates whether additional metadata should be fetched
     :return: json list of Nessie references
     """
     params = {}
-    if fetch_additional_info:
-        params["fetchAdditionalInfo"] = "true"
+    if fetch_all:
+        params["fetch"] = "ALL"
     return cast(dict, _get(base_url + "/trees", auth, ssl_verify=ssl_verify, params=params))
 
 
@@ -171,7 +171,7 @@ def list_tables(
     hash_on_ref: Optional[str] = None,
     max_result_hint: Optional[int] = None,
     page_token: Optional[str] = None,
-    query_expression: Optional[str] = None,
+    query_filter: Optional[str] = None,
     ssl_verify: bool = True,
 ) -> list:
     """Fetch a list of all tables from a known reference.
@@ -182,19 +182,19 @@ def list_tables(
     :param hash_on_ref: hash on reference
     :param max_result_hint: hint for the server, maximum number of results to return
     :param page_token: the token retrieved from a previous page returned for the same ref
-    :param query_expression: A CEL expression that allows advanced filtering capabilities
+    :param query_filter: A CEL expression that allows advanced filtering capabilities
     :param ssl_verify: ignore ssl errors if False
     :return: json list of Nessie table names
     """
     params = {}
     if max_result_hint:
-        params["max"] = str(max_result_hint)
+        params["maxRecords"] = str(max_result_hint)
     if hash_on_ref:
         params["hashOnRef"] = hash_on_ref
     if page_token:
         params["pageToken"] = page_token
-    if query_expression:
-        params["query_expression"] = query_expression
+    if query_filter:
+        params["filter"] = query_filter
     return cast(list, _get(base_url + "/trees/tree/{}/entries".format(ref), auth, ssl_verify=ssl_verify, params=params))
 
 
@@ -205,7 +205,7 @@ def list_logs(
     hash_on_ref: Optional[str] = None,
     ssl_verify: bool = True,
     max_records: Optional[int] = None,
-    fetch_additional_info: bool = False,
+    fetch_all: bool = False,
     **filtering_args: Any,
 ) -> dict:
     """Fetch a list of all logs from a known starting reference.
@@ -216,6 +216,7 @@ def list_logs(
     :param hash_on_ref: hash on reference
     :param max_records: maximum number of entries to return
     :param ssl_verify: ignore ssl errors if False
+    :param fetch_all: indicates whether additional metadata should be fetched
     :param filtering_args: All of the args used to filter the log
     :return: json dict of Nessie logs
     """
@@ -223,9 +224,9 @@ def list_logs(
     if hash_on_ref:
         params["hashOnRef"] = hash_on_ref
     if max_records:
-        params["max"] = max_records
-    if fetch_additional_info:
-        params["fetchAdditionalInfo"] = "true"
+        params["maxRecords"] = max_records
+    if fetch_all:
+        params["fetch"] = "ALL"
     return cast(dict, _get(base_url + "/trees/tree/{}/log".format(ref), auth, ssl_verify=ssl_verify, params=filtering_args))
 
 
