@@ -21,9 +21,10 @@ from .branch import branch_
 from .cherry_pick import cherry_pick
 from .config import config
 from .content import content
+from .diff import diff
 from .log import log
 from .merge import merge
 from .remote import remote
 from .tag import tag
 
-__all__ = ["remote", "tag", "branch_", "cherry_pick", "config", "log", "merge", "content"]
+__all__ = ["remote", "tag", "branch_", "cherry_pick", "config", "log", "merge", "content", "diff"]
