@@ -43,7 +43,7 @@ from ..decorators import error_handler, pass_client
 @click.option(
     "-x",
     "--extended",
-    "fetch_additional_info",
+    "fetch_all",
     is_flag=True,
     help="Retrieve additional metadata for a branch, such as number of commits ahead/behind, "
     "info about the HEAD commit, number of total commits, or the common ancestor hash.",
@@ -61,7 +61,7 @@ def branch_(
     branch: str,
     base_ref: str,
     expected_hash: str,
-    fetch_additional_info: bool,
+    fetch_all: bool,
 ) -> None:
     """Branch operations.
 
@@ -93,7 +93,7 @@ def branch_(
 
     """
     results = handle_branch_tag(
-        ctx.nessie, is_list, delete, branch, hash_on_ref, base_ref, True, ctx.json, force, ctx.verbose, fetch_additional_info, expected_hash
+        ctx.nessie, is_list, delete, branch, hash_on_ref, base_ref, True, ctx.json, force, ctx.verbose, fetch_all, expected_hash
     )
     if ctx.json:
         click.echo(results)
