@@ -238,12 +238,46 @@ class OperationsSchema(OneOfSchema):
         raise Exception("Unknown object type: {}".format(obj.__class__.__name__))
 
 
+@attr.dataclass
+class CommitMeta:
+    """Dataclass for commit metadata."""
+
+    hash_: str = desert.ib(fields.Str(data_key="hash"), default=None)
+    commitTime: datetime = desert.ib(fields.DateTime(), default=None)
+    authorTime: datetime = desert.ib(fields.DateTime(), default=None)
+    committer: str = attr.ib(default=None, metadata=desert.metadata(fields.Str(allow_none=True)))
+    author: str = attr.ib(default=None, metadata=desert.metadata(fields.Str(allow_none=True)))
+    signedOffBy: str = attr.ib(default=None, metadata=desert.metadata(fields.Str(allow_none=True)))
+    message: str = attr.ib(default=None, metadata=desert.metadata(fields.Str(allow_none=True)))
+    properties: dict = desert.ib(fields.Dict(), default=None)
+
+
+CommitMetaSchema = desert.schema_class(CommitMeta)
+
+
+@attr.dataclass
+class ReferenceMetadata:
+    """Dataclass for Nessie ReferenceMetadata."""
+
+    commit_meta_of_head: CommitMeta = desert.ib(fields.Nested(CommitMetaSchema, data_key="commitMetaOfHEAD", allow_none=True))
+    num_commits_ahead: int = attr.ib(default=None, metadata=desert.metadata(fields.Int(allow_none=True, data_key="numCommitsAhead")))
+    num_commits_behind: int = attr.ib(default=None, metadata=desert.metadata(fields.Int(allow_none=True, data_key="numCommitsBehind")))
+    common_ancestor_hash: str = attr.ib(default=None, metadata=desert.metadata(fields.Str(allow_none=True, data_key="commonAncestorHash")))
+    num_total_commits: str = attr.ib(default=None, metadata=desert.metadata(fields.Int(allow_none=True, data_key="numTotalCommits")))
+
+
+ReferenceMetadataSchema = desert.schema_class(ReferenceMetadata)
+
+
 @attr.dataclass
 class Reference:
     """Dataclass for Nessie Reference."""
 
     name: str = desert.ib(fields.Str())
     hash_: Optional[str] = attr.ib(default=None, metadata=desert.metadata(fields.Str(data_key="hash", allow_none=True)))
+    metadata: Optional[ReferenceMetadata] = attr.ib(
+        default=None, metadata=desert.metadata(fields.Nested(ReferenceMetadataSchema, allow_none=True, data_key="metadata"))
+    )
 
 
 @attr.dataclass
@@ -329,23 +363,6 @@ class Entries:
 EntriesSchema = desert.schema_class(Entries)
 
 
-@attr.dataclass
-class CommitMeta:
-    """Dataclass for commit metadata."""
-
-    hash_: str = desert.ib(fields.Str(data_key="hash"), default=None)
-    commitTime: datetime = desert.ib(fields.DateTime(), default=None)
-    authorTime: datetime = desert.ib(fields.DateTime(), default=None)
-    committer: str = attr.ib(default=None, metadata=desert.metadata(fields.Str(allow_none=True)))
-    author: str = attr.ib(default=None, metadata=desert.metadata(fields.Str(allow_none=True)))
-    signedOffBy: str = attr.ib(default=None, metadata=desert.metadata(fields.Str(allow_none=True)))
-    message: str = attr.ib(default=None, metadata=desert.metadata(fields.Str(allow_none=True)))
-    properties: dict = desert.ib(fields.Dict(), default=None)
-
-
-CommitMetaSchema = desert.schema_class(CommitMeta)
-
-
 @attr.dataclass
 class LogEntry:
     """Dataclass for commit log entries."""
@@ -401,3 +418,35 @@ class MultiContents:
 
 
 MultiContentSchema = desert.schema_class(MultiContents)
+
+
+@attr.dataclass
+class DiffEntry:
+    """Dataclass for a Diff."""
+
+    content_key: ContentKey = desert.ib(fields.Nested(ContentKeySchema, data_key="key"))
+    from_content: Content = desert.ib(fields.Nested(ContentSchema, default=None, data_key="from", allow_none=True))
+    to_content: Content = desert.ib(fields.Nested(ContentSchema, default=None, data_key="to", allow_none=True))
+
+    def pretty_print(self: "DiffEntry") -> str:
+        """Print out for cli."""
+        # pylint: disable=E1101
+        from_output = f"{self.from_content.pretty_print()}" if self.from_content else ""
+        to_output = f"{self.to_content.pretty_print()}" if self.to_content else ""
+        return (
+            f"ContentKey: {self.content_key.to_path_string()}\nFROM:\n\t{from_output}\nTO:\n{to_output}"
+            f"\n----------------------------------------"
+        )
+
+
+DiffEntrySchema = desert.schema_class(DiffEntry)
+
+
+@attr.dataclass
+class DiffResponse:
+    """Dataclass for a DiffResponse."""
+
+    diffs: List[DiffEntry] = desert.ib(fields.List(fields.Nested(DiffEntrySchema(), data_key="diffs")))
+
+
+DiffResponseSchema = desert.schema_class(DiffResponse)
